/* linux16/include/linux16/lbios.h
 * (C) 1995 Chad Page
 *
 * This file provides the basic definition for LBIOS and it's functions...
 */

/* 
 * This is the basic call, routed by the system layer into either the internal
 * LBIOS or the external interrupt-based one.
 */

/* The various sizes of LBIOS_callX allow saving stack pushes when doing these
 * calls */

void _FUNCPROTO(VBIOS_call1, (__uint r1));
void _FUNCPROTO(VBIOS_call2, (__uint r1, __uint r2));
void _FUNCPROTO(VBIOS_call3, (__uint r1, __uint r2, __uint r3));
void _FUNCPROTO(VBIOS_call4, (__uint r1, __uint r2, __uint r3, __uint r4));

/*
 * Some notes about LBIOS calls : any pointer is assumed to be in-kernel.
 * Even outside-of-kernel LBIOSes will *only* recognize kernel-level calls
 * by screening the calling CS. 
 *
 * The #defines kill type checking, but until we get a compiler with the inline
 * keyword it's either this or using .text segment space for all of these (ick) 
 * We have to be careful with code space as much as possible if we're going to 
 * do everything we want to do, and even then...
 * 
 * The next step might be to have specific LBIOS calls from the functions,
 * but I'm not keen on doing that this early in LBIOS development. 
 */

#define VBIOS_createcontext() (__hcontext)VBIOS_call1(VBIOS_NEWCONTEXT)
#define VBIOS_freecontext(context) VBIOS_call2(VBIOS_FREECONTEXT, (__uint)context)
#define VBIOS_prepcontext(context) VBIOS_call2(VBIOS_PREPCONTEXT, (__uint)context)
#define VBIOS_unprepcontext(context) VBIOS_call2(VBIOS_UNPREPCONTEXT, (__uint)context)

#define VBIOS_allocmem(context, size, flags) (__hmem)VBIOS_call3(VBIOS_ALLOCMEM, context, size, flags)
#define VBIOS_freemem(context, hmem) VBIOS_call2(VBIOS_FREEMEM, context, (__uint)hmem) 
#define VBIOS_resizemem(context, hmem, newsize) VBIOS_call3(VBIOS_RESIZEMEM, context, (__uint)seg, newsize)


